@@ -22,6 +22,24 @@ input_container = "input"
 output_container = "output"
 
 
+class TaskResult:
+    def __init__(self, result, error_message, stack_trace):
+        self.result = result
+        self.error_message = error_message
+        self.stack_trace = stack_trace
+
+    @staticmethod
+    def create_from_request_entity(self, entity):
+        result, error_message, stack = None
+        if 'Result' in entity:
+            result = entity['Result']
+        if 'Error' in entity:
+            error = entity['Error']
+        if 'StackTrace' in entity:
+            trace = entity['StackTrace']
+        return TaskResult(result, error, trace)
+
+
 def singleton(class_):
     instances = {}
     def getinstance(*args, **kwargs):
@@ -205,9 +223,7 @@ class Worker:
     def get_result(self, request_id):
         guid, request_hash = self._decode_id(request_id)
         entity = self.table_client.get_entity(self.metadata_table_name, guid, request_hash)
-        if 'Result' not in entity:
-            return ""
-        return entity['Result']
+        return TaskResult.create_from_request_entity(entity)
 
     def _insert_request_metadata(self, data):
         serialized_body = json.dumps(data)
